@@ -4,6 +4,13 @@ from typing import Any, List, Tuple, Dict, Text
 import logging
 from django.db.models import Q
 from django.db import transaction
+
+from rest_framework import serializers, fields
+from vstutils.api.serializers import VSTSerializer
+from vstutils.utils import lazy_translate as __
+
+from ...api.v2.base_serializers import UserSerializer, _WithPermissionsSerializer
+
 try:
     from yaml import dump as to_yaml, CDumper as Dumper, ScalarNode
 except ImportError:  # nocv
@@ -15,18 +22,28 @@ from .vars import AbstractModel, AbstractVarsQuerySet
 from ...main import exceptions as ex, utils
 from ..validators import RegexValidator
 
-
 logger = logging.getLogger("polemarch")
 
 
+vars_help = 'List of variables to filter. Comma separated "key:value" list.'
+
+
+def variables_filter(queryset, field, value):
+    # filter applicable only to variables
+    # pylint: disable=unused-argument
+    items = value.split(",")
+    kwargs = {item.split(":")[0]: item.split(":")[1] for item in items}
+    return queryset.var_filter(**kwargs)
+
+
 def _delete_not_existing_objects(queryset, object_dict):
     queryset.exclude(name__in=[n['name'] for n in object_dict]).delete()
 
 
 # Helpfull methods
 def _get_dict(objects: AbstractVarsQuerySet, keys: List = None, tmp_dir: Text = '/tmp') -> Tuple[Dict, List]:
-    keys = keys if keys else list()
-    result = dict()
+    keys = keys if keys else []
+    result = {}
     for obj in objects:
         result[obj.name], obj_keys = obj.toDict(tmp_dir)
         keys += obj_keys
@@ -39,28 +56,30 @@ class InventoryDumper(Dumper):
     """
     yaml_representers = getattr(Dumper, 'yaml_representers', {}).copy()
     yaml_representers[type(None)] = lambda dumper, value: (
-        ScalarNode(tag=u'tag:yaml.org,2002:null', value='')
+        ScalarNode(tag='tag:yaml.org,2002:null', value='')
     )
     yaml_representers[str] = lambda dumper, value: (
-        ScalarNode(tag=u'tag:yaml.org,2002:str', value=value)
+        ScalarNode(tag='tag:yaml.org,2002:str', value=value)
     )
 
 
 # Helpfull exceptions
-class CiclicDependencyError(ex.PMException):
+class CyclicDependencyError(ex.PMException):
     _def_message = "A cyclic dependence was found. {}"
 
     def __init__(self, tp: Text = ""):
         msg = self._def_message.format(tp)
-        super(CiclicDependencyError, self).__init__(msg)
+        super().__init__(msg)
 
 
 # Block of models
 class InventoryItems(AbstractModel):
-    master_project = models.ForeignKey(blank=True, default=None, null=True,
-                                       on_delete=models.CASCADE,
-                                       related_name='slave_%(class)s',
-                                       to='main.Project')
+    master_project = models.ForeignKey(
+        null=True,
+        on_delete=models.CASCADE,
+        related_name='slave_%(class)s',
+        to='main.Project'
+    )
 
     class Meta:
         abstract = True
@@ -76,8 +95,8 @@ class HostQuerySet(AbstractVarsQuerySet):
 
 
 class Host(InventoryItems):
-    objects     = HostQuerySet.as_manager()
-    type        = models.CharField(max_length=5, default="HOST")
+    objects = HostQuerySet.as_manager()
+    type = models.CharField(max_length=5, default="HOST")
 
     types = ["HOST", "RANGE"]
 
@@ -97,44 +116,91 @@ class Host(InventoryItems):
         return hvars or None, keys
 
 
-class GroupQuerySet(AbstractVarsQuerySet):
-    # pylint: disable=no-member
+class GroupCreateMasterSerializer(VSTSerializer):
+    children = serializers.BooleanField(
+        write_only=True,
+        label='Contains groups',
+        default=False
+    )
 
-    def get_subgroups_id(self, accumulated: AbstractVarsQuerySet = None, tp: Text = "parents") -> AbstractVarsQuerySet:
-        accumulated = accumulated if accumulated else self.none()
-        list_id = self.exclude(id__in=accumulated).values_list("id", flat=True)
-        accumulated = (accumulated | list_id)
-        kw = {tp + "__id__in": list_id}
-        subs = self.model.objects.filter(**kw)
-        subs_id = subs.values_list("id", flat=True)
-        if subs_id:
-            accumulated = (accumulated | subs.get_subgroups_id(accumulated, tp))
-        return accumulated
+    class Meta:
+        __inject_from__ = 'detail'
 
-    def get_subgroups(self) -> AbstractVarsQuerySet:
-        return self.model.objects.filter(id__in=self.get_subgroups_id(tp="parents"))
+    def create(self, validated_data):
+        if 'owner' not in validated_data and 'request' in self.context:
+            validated_data['owner'] = self.context['request'].user
+        return super().create(validated_data)
 
-    def get_parents(self) -> AbstractVarsQuerySet:
-        return self.model.objects.filter(id__in=self.get_subgroups_id(tp="childrens"))
+
+class GroupCopySerializer(VSTSerializer):
+    class Meta:
+        fields = ['name']
 
 
 class Group(InventoryItems):
-    CiclicDependencyError = CiclicDependencyError
-    objects     = GroupQuerySet.as_manager()
-    hosts       = ManyToManyFieldACL(Host, related_query_name="groups")
-    parents     = ManyToManyFieldACLReverse('Group', blank=True, null=True,
-                                            related_query_name="childrens")
-    children    = models.BooleanField(default=False)
+    """
+    retrieve:
+        Return a group instance.
+
+    list:
+        Return all groups.
+
+    create:
+        Create a new group.
+
+    destroy:
+        Remove an existing group.
+
+    partial_update:
+        Update one or more fields on an existing group.
+
+    update:
+        Update a group.
+    """
+
+    CyclicDependencyError = CyclicDependencyError
+
+    hosts = ManyToManyFieldACL(Host, related_query_name="groups")
+    parents = ManyToManyFieldACLReverse('Group', blank=True, related_query_name="childrens")
+    children = models.BooleanField(default=False)
+
+    deep_parent_field = 'parents'
+    deep_parent_allow_append = True
 
     class Meta:
         default_related_name = "groups"
-        index_together = [
-            ["children"],
-            ["children", "id"],
+        indexes = [
+            models.Index(fields=["children"]),
+            models.Index(fields=["children", "id"]),
         ]
+        _list_fields = (
+            'id',
+            'name',
+            'children',
+            'from_project',
+        )
+        _detail_fields = (
+            'id',
+            'name',
+            'notes',
+            'children',
+            'owner',
+        )
+        _override_list_fields = {
+            'from_project': fields.BooleanField(label=__('Project based')),
+        }
+        _override_detail_fields = {
+            'owner': UserSerializer(read_only=True),
+            'children': fields.BooleanField(read_only=True, label='Contains groups'),
+        }
+        _serializer_class = _WithPermissionsSerializer
+        _extra_serializer_classes = {
+            'serializer_class_create': GroupCreateMasterSerializer,
+            'serializer_class_copy': GroupCopySerializer,
+        }
 
     def toDict(self, tmp_dir: Text = '/tmp') -> Tuple[Dict, List]:
-        result = dict()
+        result = {}
         hvars, keys = self.get_generated_vars(tmp_dir)
         if self.children:
             objs = self.groups
@@ -152,8 +218,8 @@ class Group(InventoryItems):
 
 
 class Inventory(InventoryItems):
-    hosts       = ManyToManyFieldACL(Host)
-    groups      = ManyToManyFieldACL(Group)
+    hosts = ManyToManyFieldACL(Host)
+    groups = ManyToManyFieldACL(Group)
 
     _to_yaml_kwargs = dict(
         Dumper=InventoryDumper,
@@ -171,16 +237,15 @@ class Inventory(InventoryItems):
         return str(self.id)  # pragma: no cover
 
     @property
-    def groups_list(self) -> GroupQuerySet:
+    def groups_list(self):
         '''
-        :return:GroupQuerySet: Mixed queryset with all groups
+        :return:BQuerySet: Mixed queryset with all groups
         '''
-        groups_list = (
-            self.groups.filter(children=False) |
-            self.groups.filter(children=True).get_subgroups()
-        )
-        groups_list = groups_list.distinct().prefetch_related("variables", "hosts")
-        return groups_list.order_by("-children", "id")
+        return self.groups\
+            .get_children(with_current=True)\
+            .distinct()\
+            .prefetch_related("variables", "hosts")\
+            .order_by("-children", "id")
 
     @property
     def hosts_list(self) -> HostQuerySet:
@@ -190,7 +255,7 @@ class Inventory(InventoryItems):
         return self.hosts.all().order_by("name")
 
     def get_inventory(self, tmp_dir='/tmp/') -> Tuple[Text, List]:
-        inv = dict(all=dict())
+        inv = {'all': {}}
         hvars, keys = self.get_generated_vars(tmp_dir)
         hosts = self.hosts.all().order_by("name")
         groups = self.groups.all().order_by("name")
@@ -205,8 +270,8 @@ class Inventory(InventoryItems):
         return to_yaml(inv, **self._to_yaml_kwargs), keys
 
     @property
-    def all_groups(self) -> GroupQuerySet:
-        return self.groups_list.distinct()
+    def all_groups(self):
+        return self.groups_list
 
     @property
     def all_hosts(self) -> HostQuerySet:
@@ -228,7 +293,7 @@ class Inventory(InventoryItems):
             inventory = cls.objects.create(name=name, **kwargs)
 
         inventory.vars = inv_json['vars']
-        created_hosts, created_groups = dict(), dict()
+        created_hosts, created_groups = {}, {}
 
         _delete_not_existing_objects(inventory.hosts, inv_json['hosts'])
         for host in inv_json['hosts']:
