@@ -1,8 +1,8 @@
 # flake8: noqa: E501
 TRANSLATION = {
     'User settings were successfully saved.': 'Пользовательские настройки были успешно сохранены.',
-    'Invalid path. Path must not contain ".." or any special characters.':
-        'Неправильный путь. Путь не должен содержать ".." и другие специальные символы.',
+    'Invalid path. Path must not contain "..", "~" or any other special characters and must be relative.':
+        'Неправильный путь. Путь не должен содержать "..", "~" и другие специальные символы, а также должен быть относительным.',
 
     # field titles and names
     'project id': 'id проекта',
